aboutsummaryrefslogtreecommitdiff
path: root/views
diff options
context:
space:
mode:
Diffstat (limited to 'views')
-rw-r--r--views/default/annotation/generic_comment.php4
-rw-r--r--views/default/css/elements/layout.php4
-rw-r--r--views/default/layout/objects/image_block.php (renamed from views/default/layout/objects/media.php)22
3 files changed, 15 insertions, 15 deletions
diff --git a/views/default/annotation/generic_comment.php b/views/default/annotation/generic_comment.php
index c6fea8b41..a7ab0a956 100644
--- a/views/default/annotation/generic_comment.php
+++ b/views/default/annotation/generic_comment.php
@@ -53,7 +53,7 @@ if ($full_view) {
</p>
HTML;
- echo elgg_view_media($commenter_icon, $body);
+ echo elgg_view_image_block($commenter_icon, $body);
} else {
// brief view
@@ -68,5 +68,5 @@ HTML;
</span>
HTML;
- echo elgg_view_media($commenter_icon, $body);
+ echo elgg_view_image_block($commenter_icon, $body);
}
diff --git a/views/default/css/elements/layout.php b/views/default/css/elements/layout.php
index 945a4a951..fce5eaed9 100644
--- a/views/default/css/elements/layout.php
+++ b/views/default/css/elements/layout.php
@@ -41,11 +41,11 @@
padding: 3px 0;
}
-.elgg-media .elgg-pict {
+.elgg-media .elgg-image {
float: left;
margin-right: 5px;
}
-.elgg-media .elgg-pict-alt {
+.elgg-media .elgg-image.elgg-alt {
float: right;
margin-left: 5px;
}
diff --git a/views/default/layout/objects/media.php b/views/default/layout/objects/image_block.php
index 2b015bd05..79f8db138 100644
--- a/views/default/layout/objects/media.php
+++ b/views/default/layout/objects/image_block.php
@@ -1,27 +1,27 @@
<?php
/**
- * Elgg media element
+ * Elgg image block pattern
*
* Common pattern where there is an image, icon, media object to the left
* and a descriptive block of text to the right.
*
* ---------------------------------------------------------------
* | | | alt |
* | picture | body | picture |
* | block | block | block |
* | | | (optional)|
* ---------------------------------------------------------------
*
* @uses $vars['body'] HTML content of the body block
* @uses $vars['pict'] HTML content of the picture block
* @uses $vars['pict_alt'] HTML content of the alternate picture block
* @uses $vars['class'] Optional additional class for media element
* @uses $vars['id'] Optional id for the media element
*/
$body = elgg_get_array_value('body', $vars, '');
-$pict_block = elgg_get_array_value('pict', $vars, '');
-$alt_pict_block = elgg_get_array_value('pict_alt', $vars, '');
+$image_block = elgg_get_array_value('image', $vars, '');
+$alt_image_block = elgg_get_array_value('image_alt', $vars, '');
$class = 'elgg-media';
$additional_class = elgg_get_array_value('class', $vars, '');
@@ -37,16 +37,16 @@ if (isset($vars['id'])) {
$body = "<div class=\"elgg-body\">$body</div>";
-if ($pict_block) {
- $pict_block = "<div class=\"elgg-pict\">$pict_block</div>";
+if ($image_block) {
+ $image_block = "<div class=\"elgg-image\">$image_block</div>";
}
-if ($alt_pict_block) {
- $alt_pict_block = "<div class=\"elgg-pict-alt\">$alt_pict_block</div>";
+if ($alt_image_block) {
+ $alt_image_block = "<div class=\"elgg-image elgg-alt\">$alt_image_block</div>";
}
echo <<<HTML
<div class="$class clearfix" $id>
- $pict_block$alt_pict_block$body
+ $image_block$alt_image_block$body
</div>
HTML;
@@ -1,27 +1,27 @@
* ---------------------------------------------------------------
* | | | alt |
- * | picture | body | picture |
+ * | image | body | image |
* | block | block | block |
* | | | (optional)|
@@ -1,27 +1,27 @@
*
* @uses $vars['body'] HTML content of the body block
- * @uses $vars['pict'] HTML content of the picture block
- * @uses $vars['pict_alt'] HTML content of the alternate picture block
+ * @uses $vars['image'] HTML content of the image block
+ * @uses $vars['image_alt'] HTML content of the alternate image block
* @uses $vars['class'] Optional additional class for media element
* @uses $vars['id'] Optional id for the media element